@@ -298,7 +298,7 @@ class Projects:
         VideoFile: tuple[str, bool],
         base: str,
         projects_base: dict[str, str],
-        iterator: dict[str, str] = None) -> None:
+        iterator: dict[str, str] = {}) -> None:
 
         """A class to handle multiple projects"""
 
